@@ -5,6 +5,8 @@
  *
  */
  
+var ip = require('ip');
+
 exports.Bootstrapper = require('./bootstrapper').Bootstrapper;
 exports.Flavor       = require('./flavor').Flavor;
 exports.Image        = require('./image').Image;
@@ -33,13 +35,23 @@ exports.serverIp = function (server) {
   }
 
   var networks,
-      interfaces;
+      interfaces,
+      pub;
 
   if (server.ips) {
     //
-    // Joyent uses the format { ips: ['23.23.23.23', '10.0.0.1'] }
+    // Joyent uses the format:
+    // * { ips: ['23.23.23.23', '10.0.0.1'] }
+    // OR
+    // * { ips: ['10.0.0.1', '23.23.23.23'] }
     //
-    return server.ips[0];
+    pub = server.ips.filter(function (addr) {
+      return ip.isPublic(addr);
+    });
+
+    return !pub.length
+      ? servers.ips[0]
+      : pub[0]
   }
   else if (server.addresses.public || server.addresses.private) {
     //
